summaryrefslogtreecommitdiff
path: root/src/mongo/db/query/find.h
diff options
context:
space:
mode:
authorDavid Storch <david.storch@10gen.com>2015-03-18 15:24:09 -0400
committerDavid Storch <david.storch@10gen.com>2015-03-18 18:17:54 -0400
commiteac8d16add28e197df59bf5fbfd45fa39b9737f7 (patch)
tree8de5faf8e9b667146c07adc0683737e161d43105 /src/mongo/db/query/find.h
parentb91ea550904b0863f6d6c96fc38150add8c1ec03 (diff)
downloadmongo-eac8d16add28e197df59bf5fbfd45fa39b9737f7.tar.gz
SERVER-17282 fix use after free in the case of a database drop during a yield
Diffstat (limited to 'src/mongo/db/query/find.h')
-rw-r--r--src/mongo/db/query/find.h10
1 files changed, 6 insertions, 4 deletions
diff --git a/src/mongo/db/query/find.h b/src/mongo/db/query/find.h
index c8511556928..2ab9e03b007 100644
--- a/src/mongo/db/query/find.h
+++ b/src/mongo/db/query/find.h
@@ -71,11 +71,13 @@ namespace mongo {
/**
* Fills out CurOp with information regarding this query's execution.
*
* Uses explain functionality to extract stats from 'exec'. 'ctx' is used to conditionalize
* whether or not we do expensive stats gathering based on the database profiling level.
*/
- void endQueryOp(const AutoGetCollectionForRead& ctx,
- PlanExecutor* exec,
+ void endQueryOp(PlanExecutor* exec,
+ int dbProfilingLevel,
int numResults,
CursorId cursorId,
CurOp* curop);
@@ -71,11 +71,13 @@ namespace mongo {
* Fills out CurOp with information regarding this query's execution.
*
- * Uses explain functionality to extract stats from 'exec'. 'ctx' is used to conditionalize
- * whether or not we do expensive stats gathering based on the database profiling level.
+ * Uses explain functionality to extract stats from 'exec'.
+ *
+ * The database profiling level, 'dbProfilingLevel', is used to conditionalize whether or not we
+ * do expensive stats gathering.
*/